@@ -2,7 +2,7 @@
 
 from email import header
 from email.utils import parsedate
-from itertools import filterfalse
+# from itertools import filterfalse
 import typer
 import pathlib2
 import json
@@ -14,15 +14,16 @@ import cairo
 import yaml
 
 
+
 # GLOBAL CONSTANTS
 __version__ = "1.0"
 __date__ = "Feb-2022"
+
 background = 0
 middleground = 1
 foreground = 2
 colors = {"white": "#ffffff", "red": "#fbd8ea", "blue": "#c4e2fa", "yellow": "#fff4d6", "violet": "#dad0ef", "green": "#edf5dc", "turquoise": "#d4f3f6"}
 
-
 # FUNCTIONS
 
 def parse_date(d: str):
@@ -589,18 +590,39 @@ def main(
     autowidth: bool = typer.Option(False, "--autowidth", "-a", help="Render width automatically"),
     linescaling: float = typer.Option(1, "--line-scaling", "-l", help="Line width scaling factor"),
     all: bool = typer.Option(False, "-all", "-A", help="All options, equivalent to -atg"),
+    output: str = typer.Option("", "--output", "-o", help="Output file name"),
     debug: bool = typer.Option(False, "--debug", "-D", help="Show debug output"),
     version: bool = typer.Option(False, "--version", help="Show version and exit", callback=version_callback)):
+    """TL: Timeline figures
+
+
+    Generates a timeline view, e.g., for clinical trials, based on a json- or yaml-formatted input FILE. Graphical output is provided in svg vector format that can be rendered by any webbrowser or directly imported into Office applications. Use below OPTIONS to manage the output style.
+
+    This program comes with ABSOLUTELY NO WARRANTY.	This is free software, and you are welcome to redistribute it under certain conditions.
+
+    TL is proudly written in functional Python. Copyright (C) Rainer Strotmann 2022. Version information under 'tl --version'
+    """
 
     if all:
         autowidth = True
         today = True
         grid = True
 
-    # read input file
+    # make output file
     infile = pathlib2.Path(file)
     inpath = pathlib2.Path(file).resolve().parent
-    outfile = inpath.joinpath(infile.stem + ".svg")
+    # outfile = inpath.joinpath(infile.stem + ".svg")
+
+    if output:
+        outpath = pathlib2.Path.cwd().joinpath(output)
+        if outpath.is_dir():
+            outfile = outpath.joinpath(infile.stem + ".svg")
+        else:
+            outfile = outpath
+    else:
+        outfile = inpath.joinpath(infile.stem + ".svg")
+
+    # read input file
     try:
         with open(infile) as f:
             tl = json.load(f)
